@@ -144,10 +144,35 @@ class Fedora(Distro):
         super(Fedora, self).install_virtualenv()
 
 
+class Suse(Distro):
+    """This covers all SuSE distributions."""
+
+    def check_pkg(self, pkg):
+        return run_command_with_code(['rpm', '-q', pkg],
+                                     check_exit_code=False)[1] == 0
+
+    def zypper_install(self, pkg, **kwargs):
+        run_command(['sudo', 'zypper', '-qn', 'install', pkg], **kwargs)
+
+    def apply_patch(self, originalfile, patchfile):
+        run_command(['patch', originalfile, patchfile])
+
+    def install_virtualenv(self):
+        if self.check_cmd('virtualenv'):
+            return
+
+        if not self.check_pkg('python-virtualenv'):
+            self.zypper_install('python-virtualenv', check_exit_code=False)
+
+        super(Suse, self).install_virtualenv()
+
+
 def get_distro():
     if (os.path.exists('/etc/fedora-release') or
-        os.path.exists('/etc/redhat-release')):
+            os.path.exists('/etc/redhat-release')):
         return Fedora()
+    elif os.path.exists('/etc/SuSE-release'):
+        return Suse()
     elif os.path.exists('/etc/debian_version'):
         return Debian()
     else:
@@ -193,7 +218,7 @@ def install_dependencies(venv=VENV):
 
     # Tell the virtual env how to "import nova"
     pthfile = os.path.join(venv, "lib", PY_VERSION, "site-packages",
-                        "keystoneclient.pth")
+                           "keystoneclient.pth")
     f = open(pthfile, 'w')
     f.write("%s\n" % ROOT)
 
@@ -227,7 +252,8 @@ def print_help():
 def parse_args():
     """Parse command-line arguments"""
     parser = optparse.OptionParser()
-    parser.add_option("-n", "--no-site-packages", dest="no_site_packages",
+    parser.add_option(
+        "-n", "--no-site-packages", dest="no_site_packages",
         default=False, action="store_true",
         help="Do not inherit packages from global Python install")
     return parser.parse_args()
